"use strict";

const robot = require("robotjs");
const maxDeckCount = require('./hearthstone-ui').maxDeckCount;
const sleep = require('sleep').sleep;

const clickUIElement = (element) => {
	robot.moveMouse(element[0], element[1]);
	robot.mouseClick();
};

const typeIn = (element, text) => {
	clickUIElement(element);
	robot.typeString(text);
};

const cardName = (card) => {
	return card.name.enUS || card;
};

const cardSpecialCase = (card) => {
	switch (card.name) {
		case 'Charge':
			return '2';
			break;
		default:
			return '';
			break;
	}
};

const searchText = (card) => {
	const name = cardName(card);
	const artist = card.artist || '';
	const specialCase = cardSpecialCase(card);
	return `${name} ${artist} ${specialCase}`;
};

// TODO(jshrake): Handle golden cards
const buildDeck = (bounds, className, cards, deckName) => {
	const ui = require('./hearthstone-ui').UI(bounds);
	// Get to the collection
	robot.setMouseDelay(100);
	for (let i = 0; i < 5; ++i) {
		clickUIElement(ui.BackButton);
	}
	// Ensure there is a free deck slot by attempting to delete the last deck
	robot.setMouseDelay(1000);
	clickUIElement(ui.CollectionButton);
	clickUIElement(ui.DeckDeleteButtons[maxDeckCount-1]);
	clickUIElement(ui.DeleteDeckConfirmationButton);
	// Search for the New Deck button, bottom up
	robot.setMouseDelay(100);
	for (let btnIdx = maxDeckCount - 1; btnIdx != 0; btnIdx--) {
		clickUIElement(ui.DeckButtons[btnIdx]);
	}
	// Choose the class
	clickUIElement(ui[className]);
	clickUIElement(ui.ChooseHeroButton);
	robot.setMouseDelay(200);
	sleep(5);
	// Build the deck
	for (let i = 0; i < cards.length; ++i) {
		const card = cards[i];
		const nextCardName = i !== cards.length - 1 ? cardName(cards[i+1]) : null;
		const clickCount = (cardName(card) === nextCardName) ? 2 : 1;
		typeIn(ui.SearchTextBox, searchText(card));
		robot.keyTap('enter');
		switch (cardName(card)) {
			// TODO(jshrake): If Feugen is not the users collection,
			// 				  this will fail
			case 'Stalagg':
				clickUIElement(ui.SecondCardPosition);
				break;
			default:
				for (let j = 0; j < clickCount; ++j) {
					clickUIElement(ui.FirstCardPosition);
				}
				i += (clickCount-1);
				break;
				
		}
		clickUIElement(ui.SearchTextBoxClear);
	}
	// Name the deck
	deckName && typeIn(ui.DeckNameTextBox, deckName);
	// Finish
	clickUIElement(ui.BackButton);
};

module.exports = {
	buildDeck
};