#!/usr/bin/env node
"use strict";

const cards = require('./cards.collectible.json');
const cheerio = require('cheerio');
const fetch = require('node-fetch');
const url = require('url');

const getCardByName = (name) => {
	return cards.find(card => card.name.enUS.toLowerCase() === name.toLowerCase());
};

const extractHearthPwnDeck = (html) => {
		const $ = cheerio.load(html);
		const deckName = $('h2.deck-title').text();
		const className = $('.t-deck-details-card-list h4').text().split(' ')[0].trim();
		const cardNames = $('#cards a').get().reduce((a, el) => {
			const count = $(el).attr('data-count');
			const name = $(el).text().trim();
			for (let i = 0; i < count; ++i) {
				a.push(name);
			}
			return a;
		}, []);
		return {
			name: deckName,
			class: className,
			cards: cardNames.map(name => getCardByName(name))
		};
};

const extractDeck = (host, html)  => {
	switch (host) {
		case 'www.hearthpwn.com':
			return extractHearthPwnDeck(html);
		default:
			throw Error(`Cannot extract deck from ${host}`)
	}
};

const fetchDeck = (deckUrl) => {
	return fetch(deckUrl)
				.then(res => {
					return res.text();
				}).then(html => {
					const host = url.parse(deckUrl).hostname;
					const deck = extractDeck(host, html);
					deck.url = deckUrl;
					return deck;
				});
};

module.exports = {
	fetchDeck
};