"use strict";

const range = (a, b) => {
	const start = (b && a) || 0;
	const end = (b && b) || a;
	return Array.apply(null, Array(end-start)).map(function (_, i) {return start + i;});
};

const maxDeckCount = 9;

const normalized = () => {
	const screen = [1440, 900];
	const m = {
			"DeckButtonBase": [1160, 120],
			"DeckDeleteButtonBase": [1209, 94],
			"DeckButtonOffset": [0, 80],
			"ClassButtonBase": [257, 274],
			"ClassButtonOffset": [200, 190],
			"BackButton": [1250, 835],
			"CollectionButton": [800, 750],
			"DeleteDeckConfirmationButton": [560, 515],
			"ChooseHeroButton": [1086, 743],
			"SearchTextBox": [714, 824],
			"SearchTextBoxClear": [824, 824],
			"FirstCardPosition": [250, 290],
			"SecondCardPosition": [500, 290],
			"DeckNameTextBox": [1085, 37],
	};
	const UI = {};
	const screenx = screen[0];
	const screeny = screen[1];
	for (let k in m) {
		if (!m.hasOwnProperty(k)) {
			continue;
		}
		UI[k] = [m[k][0]/screenx, m[k][1]/screeny];
	}
	UI.DeckButtons = range(maxDeckCount).map(i => {
		return [
			UI.DeckButtonBase[0] + i * UI.DeckButtonOffset[0],
			UI.DeckButtonBase[1] + i * UI.DeckButtonOffset[1]];
	});
	UI.DeckDeleteButtons = range(maxDeckCount).map(i => {
		return [
			UI.DeckDeleteButtonBase[0] + i * UI.DeckButtonOffset[0],
			UI.DeckDeleteButtonBase[1] + i * UI.DeckButtonOffset[1]];
	});
	UI.Warrior = [
		UI.ClassButtonBase[0] + 0 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 0 * UI.ClassButtonOffset[1]];
	UI.Shaman = [
		UI.ClassButtonBase[0] + 1 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 0 * UI.ClassButtonOffset[1]];
	UI.Rogue = [
		UI.ClassButtonBase[0] + 2 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 0 * UI.ClassButtonOffset[1]];
	UI.Paladin = [
		UI.ClassButtonBase[0] + 0 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 1 * UI.ClassButtonOffset[1]];
	UI.Hunter = [
		UI.ClassButtonBase[0] + 1 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 1 * UI.ClassButtonOffset[1]];
	UI.Druid = [
		UI.ClassButtonBase[0] + 2 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 1 * UI.ClassButtonOffset[1]];
	UI.Warlock = [
		UI.ClassButtonBase[0] + 0 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 2 * UI.ClassButtonOffset[1]];
	UI.Mage = [
		UI.ClassButtonBase[0] + 1 * UI.ClassButtonOffset[0],
		UI.ClassButtonBase[1] + 2 * UI.ClassButtonOffset[1]];
 	UI.Priest = [
 		UI.ClassButtonBase[0] + 2 * UI.ClassButtonOffset[0],
 		UI.ClassButtonBase[1] + 2 * UI.ClassButtonOffset[1]];
	return UI;
};

const elementToScreen = (el, bounds) => {
	return [
		bounds.x + el[0] * bounds.w,
		bounds.y + el[1] * bounds.h
	];
};

// Conver the normalized UI coordinates to screen space
const toScreen = (ui, bounds) => {
	const screenspace = {};
	for (let k in ui) {
		if (!ui.hasOwnProperty(k)) {
			continue;
		}
		// Handle array of arrays
		const element = ui[k];
		if (element[0] instanceof Array) {
			screenspace[k] = element.map(sub => elementToScreen(sub, bounds));
		} else {
			screenspace[k] = elementToScreen(element, bounds);
		}
	}
	return screenspace;
};

const UI = (bounds) => {
	return toScreen(normalized(), bounds);
};

module.exports = {
	UI,
	maxDeckCount
};