"use strict";

// Activate a process specified by name
const activate = (name) => {
	const osxActivate = `osascript -e 'tell application \"System Events\" to tell application \"${name}\" to activate'`;
	return require('child_process').execSync(osxActivate);
};

// Returns the width and height as an array of the window associated with the process specified by name
const getSize = (name) => {
	const osxGetSize = `osascript -e 'tell application \"System Events\" to tell application process \"${name}\" to get the size of the front window'`
	return require('child_process').execSync(osxGetSize).toString().split(",").map(x => Number(x));
};

// Returns the coordinates of the top-left corner of the window associated with the process specified by name
const getPosition = (name) => {
	const osxGetPosition = `osascript -e 'tell application \"System Events\" to tell application process \"${name}\" to get the position of the front window'`
	return require('child_process').execSync(osxGetPosition).toString().split(",").map(x => Number(x));
};

// Returns the bounds (x,y,w,h) of the window associated with the process specified by name
const getBounds = (name) => {
	const size = getSize(name);
	const pos = getPosition(name);
	return {
		x: pos[0],
		y: pos[1],
		w: size[0],
		h: size[1]
	};
};

module.exports = {
	activate,
	getSize,
	getPosition,
	getBounds
};